@@ -33,7 +33,7 @@
 ##                                                                           ##
 ###############################################################################
 
-package require Tcl 8.4
+package require Tcl 8.6-
 # XXX WS::Utils usable here? (provide dict, lassign)
 if {![llength [info command dict]]} {
     package require dict
@@ -54,7 +54,7 @@ package require uri
 package require base64
 package require html
 
-package provide WS::Channel 2.4.0
+package provide WS::Channel 2.5.0
 
 namespace eval ::WS::Channel {
 
